%define		srcdir	ImageLounge
#define		date	20220907

# rel for bumping
%define rel	1

Name:		nomacs
Version:	3.19.0
Release:	%mkrel %{?date:0.git%date.}%{rel}
Summary:	A fast and small image viewer
License:	GPLv3
Group:		Graphics/Viewers
Url:		https://www.nomacs.org/
# From https://github.com/nomacs/nomacs/ - only ImageLounge directory repacked
# Memo: tar Jcvf nomacs-%%{version}.tar.xz nomacs-%%{version}/
Source0:	%{name}-%{version}.tar.xz
Source1:	https://github.com/novomesk/nomacs-plugins/archive/%{version}/%{name}-plugins-%{version}.tar.gz
Patch0:		nomacs-not-update-version.patch
Patch1:		nomacs-quazip-qt6.patch

BuildRequires:	cmake
BuildRequires:	lcov
BuildRequires:	qttools6
BuildRequires:	cmake(QuaZip-Qt6)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(exiv2)
BuildRequires:	pkgconfig(libavif)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libjxl)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(zlib)

Requires:	qt6-avif-image-plugin
Requires:	qt6-jpegxl-image-plugin
Requires:	qt6-heic-image-plugin

%description
nomacs is an image viewer based on the Qt5 library. It is free, small, fast and
is able to handle the most common image formats including RAW images.

Additionally, synchronization of viewers running on the same computer or via
LAN is possible, which allows one to compare images and spot the differences.

This package also contains some usefull plugins for nomacs image viewer:
 * Affine transformations
 * RGB image from greyscales
 * Fake miniature filter
 * Page extractions
 * Painting

%prep
%autosetup -p1 -a 1

# plug them in
mv nomacs-plugins-%{version}/* plugins/ && rm -rf nomacs-plugins-%{version}
# plugins install path (https://github.com/nomacs/nomacs-plugins/issues/34)
sed -i 's|lib/nomacs-plugins|lib\${LIB_SUFFIX}/nomacs-plugins|' plugins/cmake/Utils.cmake

# fix SVG icon install path
sed -i cmake/UnixBuildTarget.cmake -e 's@share/pixmaps@share/icons/hicolor/scalable/apps@'

%build
%cmake_qt6 \
	-DQT_VERSION_MAJOR=6 \
	-DCMAKE_BUILD_TYPE=Release \
	-DENABLE_QUAZIP=ON \
	-DUSE_SYSTEM_QUAZIP=ON \
	-DENABLE_TRANSLATIONS=ON \
	-DENABLE_PLUGINS=ON

%cmake_build

%install
%cmake_install

# we don't want unneeded devel files
find %{buildroot} -name '*.so' -delete

%files
%doc README.md
%license license/LICENSE.GPLv3
%{_bindir}/%{name}
%{_libdir}/lib%{name}*.so*
%{_datadir}/%{name}/
%{_libdir}/nomacs-plugins/
%{_datadir}/applications/org.%{name}.ImageLounge.desktop
%{_datadir}/metainfo/org.%{name}.ImageLounge.appdata.xml
%{_iconsdir}/hicolor/scalable/*/org.%{name}.ImageLounge.svg
%{_mandir}/man1/%{name}.1.*


%changelog
* Fri Jul 12 2024 daviddavid <daviddavid> 3.19.0-1.mga10
+ Revision: 2080785
- new version: 3.19.0
- switch to Qt6

* Tue Mar 12 2024 daviddavid <daviddavid> 3.17.2295-2.mga10
+ Revision: 2049339
- enable additional usefull nomacs-plugins
- require qt-avif-image-plugin, qt-jpegxl-image-plugin and qt-heic-image-plugin

* Tue Mar 12 2024 daviddavid <daviddavid> 3.17.2295-1.mga10
+ Revision: 2049289
- new version: 3.17.2295

* Mon Oct 09 2023 daviddavid <daviddavid> 3.17.2287-4.mga10
+ Revision: 1993969
- fix release tag

* Mon Oct 09 2023 daviddavid <daviddavid> 3.17.2287-3.git20220907.1.mga10
+ Revision: 1993763
- new version: 3.17.2287
- rebuild for new exiv2 0.28.0

* Sat Sep 02 2023 daviddavid <daviddavid> 3.17.2206-3.git20220907.3.mga10
+ Revision: 1983544
- rebuild for new quazip 1.4

* Mon Dec 12 2022 ns80 <ns80> 3.17.2206-3.git20220907.2.mga9
+ Revision: 1921088
- rebuild for new libtiff

* Fri Dec 02 2022 daviddavid <daviddavid> 3.17.2206-3.git20220907.1.mga9
+ Revision: 1913995
- fix release tag

* Wed Nov 02 2022 ghibo <ghibo> 3.17.2206-3.git20220907.mga9
+ Revision: 1901478
- Rebuild for newer opencv

* Tue Nov 01 2022 ghibo <ghibo> 3.17.2206-2.git20220907.mga9
+ Revision: 1900943
- Rebuild against opencv 4.6.0

* Thu Oct 06 2022 papoteur <papoteur> 3.17.2206-1.git20220907.mga9
+ Revision: 1895008
- Update to 3.17.2206 with lastest commits until 2022-09-07

* Mon Apr 04 2022 umeabot <umeabot> 3.16.224-7.mga9
+ Revision: 1844000
- Mageia 9 Mass Rebuild

* Mon Dec 27 2021 wally <wally> 3.16.224-6.mga9
+ Revision: 1764538
- rebuild for opencv 4.5.5

* Tue May 18 2021 daviddavid <daviddavid> 3.16.224-5.mga9
+ Revision: 1725479
- switch to new quazip 1.0
- add upstream patch to support new quazip 1.0

* Thu Dec 17 2020 umeabot <umeabot> 3.16.224-4.mga8
+ Revision: 1659134
- Rebuild for new Qt5

* Tue Nov 03 2020 akien <akien> 3.16.224-3.mga8
+ Revision: 1641971
- Rebuild against opencv 4.5

* Wed Sep 09 2020 zezinho <zezinho> 3.16.224-2.mga8
+ Revision: 1623892
- rebuild against libraw20

* Mon Aug 10 2020 daviddavid <daviddavid> 3.16.224-1.mga8
+ Revision: 1612611
- new version: 3.16.224

* Tue Jul 14 2020 daviddavid <daviddavid> 3.15.1616-1.mga8
+ Revision: 1605915
- new version: 3.15.1616

* Fri Mar 27 2020 daviddavid <daviddavid> 3.14.2-1.mga8
+ Revision: 1561086
- new version: 3.14.2

* Sun Mar 15 2020 daviddavid <daviddavid> 3.14-1.mga8
+ Revision: 1556430
- new version: 3.14

* Wed Feb 19 2020 umeabot <umeabot> 3.12-6.mga8
+ Revision: 1544334
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 3.12-5.mga8
+ Revision: 1482887
- add patch to fix build with opencv 4.2.0
- rebuild for new opencv 4.2.0
+ wally <wally>
- build with new cmake macros

* Thu May 16 2019 daviddavid <daviddavid> 3.12-4.mga7
+ Revision: 1398043
- add patch to fix build with exiv2 0.27.1
- rebuild for new exiv2 0.27.1

* Sun Mar 31 2019 umeabot <umeabot> 3.12-3.mga7
+ Revision: 1383535
- Qt5 Rebuild

* Sat Dec 29 2018 luigiwalser <luigiwalser> 3.12-2.mga7
+ Revision: 1346060
- rebuild for exiv2

* Wed Oct 24 2018 daviddavid <daviddavid> 3.12-1.mga7
+ Revision: 1325032
- new version: 3.12

* Thu Sep 06 2018 daviddavid <daviddavid> 3.10.2-2.mga7
+ Revision: 1257515
- rebuild for new libraw 0.19.0

* Sun Jul 15 2018 daviddavid <daviddavid> 3.10.2-1.mga7
+ Revision: 1243740
- new version: 3.10.2

* Sat Jul 07 2018 daviddavid <daviddavid> 3.10.1-1.mga7
+ Revision: 1242407
- new version: 3.10.1

* Thu Jul 05 2018 daviddavid <daviddavid> 3.10.0-1.mga7
+ Revision: 1241720
- new version: 3.10.0
- remove merded upstream patch

* Sun Jun 03 2018 daviddavid <daviddavid> 3.8.1-4.mga7
+ Revision: 1233829
- add upstream patch to fix build with new Qt5 >= 5.11.0

* Thu Apr 12 2018 daviddavid <daviddavid> 3.8.1-3.mga7
+ Revision: 1217797
- rebuild for new opencv 3.4.1

* Sat Apr 07 2018 shlomif <shlomif> 3.8.1-2.mga7
+ Revision: 1215913
- Revise broken English

* Sat Apr 07 2018 daviddavid <daviddavid> 3.8.1-1.mga7
+ Revision: 1215889
- new version: 3.8.1
- remove merged upstream patch

* Mon Mar 26 2018 daviddavid <daviddavid> 3.8.0-2.mga7
+ Revision: 1212519
- add upstream patch to fix build (undefined reference to vtable) with Qt 5.9.4

* Sat Jan 13 2018 daviddavid <daviddavid> 3.8.0-1.mga7
+ Revision: 1192505
- new version: 3.8.0

* Tue Jun 20 2017 neoclust <neoclust> 3.6.1-2.mga6
+ Revision: 1108016
- Rebuild against new exiv2

* Wed Apr 26 2017 akien <akien> 3.6.1-1.mga6
+ Revision: 1097636
- Version 3.6.1

* Wed Dec 28 2016 neoclust <neoclust> 3.2.0-2.mga6
+ Revision: 1078426
- Rebuild for new libraw

* Wed Jun 22 2016 daviddavid <daviddavid> 3.2.0-1.mga6
+ Revision: 1037179
- new version: 3.2.0
- port to Qt5 now
- update Source URL
- add a patch to use system quazip-qt5
- add an upstream patch to fix an ambiguous call to abs

* Mon Dec 28 2015 tv <tv> 1.6.4-5.mga6
+ Revision: 916253
- rebuild for new libraw

* Wed Oct 15 2014 umeabot <umeabot> 1.6.4-4.mga6
+ Revision: 746198
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.6.4-3.mga5
+ Revision: 682912
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 luigiwalser <luigiwalser> 1.6.4-2.mga5
+ Revision: 668362
- rebuild

* Mon Feb 24 2014 dams <dams> 1.6.4-1.mga5
+ Revision: 596211
- new version 1.6.4

* Mon Feb 10 2014 dams <dams> 1.6.2-1.mga5
+ Revision: 589055
- new version 1.6.2

* Wed Feb 05 2014 wally <wally> 1.4.0-3.mga5
+ Revision: 583417
- rebuild for new libraw

* Sat Oct 19 2013 umeabot <umeabot> 1.4.0-2.mga4
+ Revision: 530660
- Mageia 4 Mass Rebuild

* Sat Jul 27 2013 matteo <matteo> 1.4.0-1.mga4
+ Revision: 458830
- new version

* Fri Jun 21 2013 matteo <matteo> 1.2.0-1.mga4
+ Revision: 445548
- new version

* Tue May 28 2013 wally <wally> 1.0.2-1.mga4
+ Revision: 429648
- new version 1.0.2
+ matteo <matteo>
- new version

* Sat Jan 12 2013 umeabot <umeabot> 0.4.0-2.mga3
+ Revision: 361045
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 17 2012 matteo <matteo> 0.4.0-1.mga3
+ Revision: 307418
- fixed group
- added desktop file validation
- imported package nomacs

